Index: res_indications.c
===================================================================
RCS file: /usr/cvsroot/asterisk/res/res_indications.c,v
retrieving revision 1.3
diff -u -r1.3 res_indications.c
--- res_indications.c	13 Aug 2003 15:25:16 -0000	1.3
+++ res_indications.c	28 Aug 2003 10:00:25 -0000
@@ -32,7 +32,8 @@
 #include <asterisk/module.h>
 #include <asterisk/translate.h>
 #include <asterisk/indications.h>
-
+#include <asterisk/app.h>
+#include <asterisk/options.h>
 
 // Globals
 static const char dtext[] = "Indications Configuration";
@@ -334,6 +335,51 @@
 	return 0;
 }
 
+static int handle_dialtone(struct ast_channel *chan, void *data)
+{
+    struct tone_zone_sound *ts;
+    int res;
+    char tmp[256];
+    char *stringp, *mailbox, *stimeout;
+    int timeout;
+
+    stringp = mailbox = stimeout = NULL;
+    timeout = 10000;
+
+    strncpy(tmp, data, sizeof(tmp)-1),
+    stringp = tmp;
+
+    stimeout = strsep(&stringp, "|");
+    if(stimeout && stimeout[0]) {
+	mailbox = strsep(&stringp, "|");
+	timeout = atoi(stimeout) * 1000;
+    }
+
+
+    if(mailbox && ast_app_has_voicemail(mailbox)) {
+	ts = ast_get_indication_tone(chan->zone, "dialrecall");
+	if (option_verbose > 2)
+	    ast_verbose(VERBOSE_PREFIX_3 "Dialtone: playing dialrecall for %d mili seconds\n", timeout);
+    } else {
+	ts = ast_get_indication_tone(chan->zone, "dial");
+	if (option_verbose > 2)
+	    ast_verbose(VERBOSE_PREFIX_3 "Dialtone: playing dial for %d mili seconds\n", timeout);
+    }
+
+    ast_playtones_stop(chan);
+    res = ast_playtones_start(chan, 0, ts->data, 0);
+
+    if (res)
+	ast_log(LOG_NOTICE,"Unable to start playtones\n");
+
+    if (!res) {
+	res = ast_waitfordigit(chan, (const int) timeout);
+	ast_playtones_stop(chan);
+    }
+    
+    return res;
+}
+
 /*
  * CLI entries for commands provided by this module
  */
@@ -366,6 +412,7 @@
 	ast_cli_unregister(&show_indications_cli);
 	ast_unregister_application("Playlist");
 	ast_unregister_application("StopPlaylist");
+	ast_unregister_application("Dialtone");
 	return 0;
 }
 
@@ -378,7 +425,17 @@
 	ast_cli_register(&show_indications_cli);
 	ast_register_application("Playtones", handle_playtones, "Play a tone list","Play a tone list, either registered (through indications.conf) or a direct list of tones and durations.");
 	ast_register_application("StopPlaytones", handle_stopplaytones, "Stop playing a tone list","Stop playing a tone list");
-
+	
+	ast_register_application(
+	    "Dialtone",
+	    handle_dialtone,
+	    "Play a dialtone while awaiting extension ",
+	    "Dialtone([timeout[|mailbox]]): Plays a dialtone,including an initial stutter\n"
+	    "on new voicemail, if optional mailbox is specified, while simultaneously waiting\n"
+	    "for the user to begin typing an extension or the timeout occurs.  Timeout parameter\n"
+	    "is in seconds.  Default timeout is 60 seconds.  Returns 0\n"
+	);
+	
 	return 0;
 }
 
